@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,12 +69,12 @@ public class SimMessageAccess implements MessagingMessageAccess {
             this.name = name;
             this.args = args;
         }
-        
-        
+
+
         public String getName() {
             return name;
         }
-        
+
         public Object[] getArgs() {
             return args;
         }
@@ -83,20 +83,20 @@ public class SimMessageAccess implements MessagingMessageAccess {
     private final List<Call> called = new ArrayList<Call>();
     private MessagingMessage templateMessage;
     private MessagingPart templatePart;
-    
+
     public List<Call> getCalls() {
         return called;
     }
-    
+
     public void setTemplateMessage(final MessagingMessage templateMessage) {
         this.templateMessage = templateMessage;
     }
 
-    public MessagingPart getAttachment(String folder, String messageId, String sectionId) throws MessagingException {
+    public MessagingPart getAttachment(final String folder, final String messageId, final String sectionId) throws MessagingException {
         called.add(new Call("getAttachment", folder, messageId, sectionId));
         return templatePart;
     }
-    
+
     public void appendMessages(final String folder, final MessagingMessage[] messages) throws MessagingException {
         called.add(new Call("appendMessages", folder, messages));
     }
@@ -114,7 +114,7 @@ public class SimMessageAccess implements MessagingMessageAccess {
         called.add(new Call("getAllMessages", folder, indexRange, sortField, order, fields));
         return new ArrayList<MessagingMessage>(Arrays.asList(templateMessage));
     }
-    
+
 
     public MessagingMessage getMessage(final String folder, final String id, final boolean peek) throws MessagingException {
         called.add(new Call("getMessage", folder, id, peek));
@@ -158,7 +158,7 @@ public class SimMessageAccess implements MessagingMessageAccess {
     /* (non-Javadoc)
      * @see com.openexchange.messaging.MessagingMessageAccess#resolveContent(java.lang.String, java.lang.String, java.lang.String)
      */
-    public MessagingContent resolveContent(String folder, String id, String referenceId) throws MessagingException {
+    public MessagingContent resolveContent(final String folder, final String id, final String referenceId) throws MessagingException {
         // TODO Auto-generated method stub
         return null;
     }
