@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import com.openexchange.exceptions.LocalizableStrings;
 
 /**
  * {@link MessagingExceptionMessages} - Exception messages for {@link MessagingException} that needs to be translated.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @since Open-Xchange v6.16
  */
@@ -97,13 +97,13 @@ public final class MessagingExceptionMessages implements LocalizableStrings {
 
     // Unknown messaging content: %1$s.
     public static final String UNKNOWN_MESSAGING_CONTENT_MSG = "Unknown messaging content: %1$s.";
-    
+
     // Unknown messaging service: %1$s.
     public static final String UNKNOWN_MESSAGING_SERVICE_MSG = "Unknown messaging service: %1$s.";
-    
+
     //  Missing parameter: %1$s
     public static final String MISSING_PARAMETER_MSG = "Missing parameter: %1$s.";
-    
+
     // Invalid parameter: %1$s with value '%2$s'.
     public static final String INVALID_PARAMETER_MSG = "Invalid parameter: %1$s with value '%2$s'.";
 
@@ -128,6 +128,9 @@ public final class MessagingExceptionMessages implements LocalizableStrings {
     // No attachment found with section identifier %1$s in message %2$s in folder %3$s.
     public static final String ATTACHMENT_NOT_FOUND_MSG = "No attachment found with section identifier %1$s in message %2$s in folder %3$s.";
 
+    // Message %1$s not found in folder %2$s.
+    public static final String MESSAGE_NOT_FOUND_MSG = "Message %1$s not found in folder %2$s.";
+
     /**
      * Initializes a new {@link MessagingExceptionMessages}.
      */
